@@ -44,7 +44,7 @@ __plugin_meta__ = PluginMetadata(
         "unique_name": "petpet",
         "example": "摸 @小Q\n摸 114514\n摸 自己\n摸 [图片]",
         "author": "meetwq <meetwq@gmail.com>",
-        "version": "0.3.17.1",
+        "version": "0.3.18",
     },
 )
 
@@ -217,8 +217,10 @@ def create_matchers():
         ).append_handler(handler(meme), parameterless=[split_msg()])
 
     def random_handler() -> T_Handler:
-        def handle(matcher: Matcher):
-            random_meme = random.choice([meme for meme in memes if check_flag(meme)])
+        def handle(matcher: Matcher, user_id: str = get_user_id()):
+            random_meme = random.choice(
+                [meme for meme in memes if meme_manager.check(user_id, meme)]
+            )
             handler_ = Dependent[Any].parse(
                 call=handler(random_meme),
                 parameterless=[split_msg()],
