@@ -5,7 +5,7 @@ from nonebot import get_driver
 
 
 class Config(BaseModel, extra=Extra.ignore):
-    petpet_command_start: str = ""
+    petpet_command_start: List[str] = [""]
     petpet_resource_url: str = "https://ghproxy.com/https://raw.githubusercontent.com/noneplugin/nonebot-plugin-petpet/v0.3.x/resources"
     petpet_disabled_list: List[str] = []
     petpet_gif_max_size: float = 10
